==> kwave_0.8.12-1.orig.tar.bz2: kwave-0.8.12/plugins/codec_wav/RecoveryBuffer.h <==
/*************************************************************************
     RecoveryBuffer.cpp  - buffer for reconstructed audio file data
                             -------------------
    begin                : Sun May 12 2002
    copyright            : (C) 2002 by Thomas Eschenbacher
    email                : Thomas.Eschenbacher@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _RECOVERY_BUFFER_H_
#define _RECOVERY_BUFFER_H_

#include "config.h"

#include <QtCore/QByteArray>

#include "RecoverySource.h"

namespace Kwave
{
    class RecoveryBuffer: public Kwave::RecoverySource
    {
    public:
	/**
	 * Constructor
	 * @param offset position in the repaired file
	 * @param length number of recovered bytes
	 * @param buffer a buffer with 'length' bytes of data
	 */
	RecoveryBuffer(quint64 offset, quint64 length, char *buffer);

	/** Destructor */
	virtual ~RecoveryBuffer() {}

	/** implementation of RecoverySource::read */
	virtual qint64 read(quint64 offset, char *data, unsigned int bytes);

    private:

	/** buffer with recovered data */
	QByteArray m_buffer;
    };
}

#endif /* _RECOVERY_BUFFER_H_ */

//***************************************************************************
//***************************************************************************

==> kwave_0.9.0-1.orig.tar.bz2: kwave-0.9.0/plugins/codec_wav/RecoveryBuffer.h <==
/*************************************************************************
     RecoveryBuffer.cpp  - buffer for reconstructed audio file data
                             -------------------
    begin                : Sun May 12 2002
    copyright            : (C) 2002 by Thomas Eschenbacher
    email                : Thomas.Eschenbacher@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RECOVERY_BUFFER_H
#define RECOVERY_BUFFER_H

#include "config.h"

#include <QtCore/QByteArray>

#include "RecoverySource.h"

namespace Kwave
{
    class RecoveryBuffer: public Kwave::RecoverySource
    {
    public:
	/**
	 * Constructor
	 * @param offset position in the repaired file
	 * @param length number of recovered bytes
	 * @param buffer a buffer with 'length' bytes of data
	 */
	RecoveryBuffer(quint64 offset, quint64 length, char *buffer);

	/** Destructor */
	virtual ~RecoveryBuffer() {}

	/** implementation of RecoverySource::read */
	virtual qint64 read(quint64 offset, char *data, unsigned int bytes);

    private:

	/** buffer with recovered data */
	QByteArray m_buffer;
    };
}

#endif /* RECOVERY_BUFFER_H */

//***************************************************************************
//***************************************************************************
